asr.test.test\_core\_results
============================

.. automodule:: asr.test.test_core_results

   
   
   .. rubric:: Functions

   
   .. autofunction:: test_read_old_format
   .. autofunction:: test_reading_older_version
   .. autofunction:: test_reading_result
   .. autofunction:: test_results_object
   
   

   
   
   .. rubric:: Classes

   
   .. autoclass:: MyResult
      :members:
   .. autoclass:: MyResultVer0
      :members:
   .. autoclass:: MyWebPanel
      :members:
   
   

   
   
   